#!/usr/bin/env python
import sys
from django.conf import settings

if not settings.configured:
    settings.configure(
        DATABASES = {
            'default': {
                'ENGINE': 'django.db.backends.sqlite3',
                'NAME': 'dev.db',
            }
        },
        INSTALLED_APPS=[
            'django.contrib.sessions',
            'django.contrib.staticfiles',
            'crossix',
        ],
        STATIC_ROOT='/tmp/crossix_test_static/',
        STATIC_URL='/static/',
        ROOT_URLCONF='crossix.urls',
    )

def runtests(*test_args):
    from django.test.simple import DjangoTestSuiteRunner
    test_runner = DjangoTestSuiteRunner(verbosity=1)
    failures = test_runner.run_tests(['crossix', ])
    if failures:
        sys.exit(failures)

if __name__ == '__main__':
    runtests(*sys.argv[1:])




import markdown

from django import template
register = template.Library()

from .. import models


@register.inclusion_tag('pages/minipage.html')
def include_page(page_name):
    try:
        page = models.Page.objects.get(name=page_name)
    except models.Page.DoesNotExist:
        return {'html': ''}

    html = markdown.markdown(page.content)
    return {'html': html}



# -*- coding: utf-8 -*-

import datetime

from django.db import models
from django.utils.translation import ugettext_lazy as _


class Page(models.Model):
    name = models.SlugField(_(u"name"), unique=True, editable=False)
    title = models.CharField(_(u"title"), max_length=100, unique=True)
    content = models.TextField(_(u"content"))

    class Meta:
        verbose_name = _(u"page")
        verbose_name_plural = _(u"pages")

    def __str__(self):
        return self.title



# -*- coding: utf-8 -*-

import datetime

from django.db import models
from django.utils.translation import ugettext_lazy as _

GENDER_CHOICES = (('M', 'Homme'), ('F', 'Femme'))
SCHOOL_CHOICES = (
    ('X', 'Polytechnique'),
    ('HEC', 'HEC'),
    ('ECP', 'Centrale'),
    ('OTHER', 'Accompagnant'),
    )
YEAR_CHOICES = list((str(x), str(x)) for x in range(datetime.date.today().year - 19, 1900, -1))


def next_edition():
    return Edition.objects.next()


class EditionManager(models.Manager):
    def next(self):
        try:
            return self.filter(date__gt=datetime.date.today()).all()[0]
        except (Edition.DoesNotExist, IndexError):
            return None

    def last(self):
        try:
            return self.filter(date__lte=datetime.date.today()).latest('date')
        except Edition.DoesNotExist:
            return None


class Edition(models.Model):
    """An edition of the cross."""
    LOCATION_X = 'X'
    LOCATION_HEC = 'HEC'
    LOCATION_ECP = 'ECP'

    LOCATION_CHOICES = (
        (LOCATION_X, _(u"École polytechnique")),
        (LOCATION_HEC, _(u"HEC")),
        (LOCATION_ECP, _(u"École Centrale")),
    )

    date = models.DateField(verbose_name=_('date'), unique=True)
    close_registrations = models.DateField(verbose_name=_('registration deadline'), unique=True)
    location = models.CharField(verbose_name=_('location'), max_length=3, choices=LOCATION_CHOICES)

    objects = EditionManager()

    class Meta:
        verbose_name = _(u"edition")
        verbose_name_plural = _(u"editions")

    def __str__(self):
        return u'%s at %s' % (self.date, self.get_location_display())

class Category(models.Model):
    """Category of participants (junior...senior)"""
    name = models.CharField(_('name'), max_length=200, unique=True)
    gender = models.CharField(verbose_name=_('gender'), max_length=1, choices=GENDER_CHOICES)
    min_age = models.IntegerField(_('min_age'))

    class Meta:
        verbose_name = _(u"category")
        verbose_name_plural = _(u"categories")

    def __str__(self):
        return self.name

    @property
    def max_birth_year(self):
        return datetime.date.today().year - self.min_age


class Participant(models.Model):
    """A participant."""
    firstname = models.CharField(verbose_name=_('firstname'), max_length=200)
    lastname = models.CharField(verbose_name=_('lastname'), max_length=200)
    birthyear = models.CharField(verbose_name=_('birthyear'), max_length=4, choices=YEAR_CHOICES, blank=True,null=True)
    gender = models.CharField(verbose_name=_('gender'), max_length=1, choices=GENDER_CHOICES)
    email = models.EmailField(verbose_name=_('email'))
    category = models.ForeignKey(Category, verbose_name=_('category'), on_delete=models.CASCADE)
    school = models.CharField(verbose_name=_('school'), max_length=5, choices=SCHOOL_CHOICES)
    promo = models.IntegerField(verbose_name=_('promo'), blank=True, null=True)

    last_edition = models.ForeignKey(Edition, default=next_edition, on_delete=models.CASCADE)

    def __str__(self):
        return '%s %s %s <%s> (%s %d)' % (self.gender, self.firstname, self.lastname, self.email,
            self.school, self.promo or 0)
  



# -*- coding: utf-8 -*-

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Page',
            fields=[
                ('id', models.AutoField(serialize=False, auto_created=True, primary_key=True, verbose_name='ID')),
                ('name', models.SlugField(verbose_name='name', unique=True, editable=False)),
                ('title', models.CharField(verbose_name='title', unique=True, max_length=100)),
                ('content', models.TextField(verbose_name='content')),
            ],
            options={
                'verbose_name': 'page',
                'verbose_name_plural': 'pages',
            },
        ),
    ]



#!/usr/bin/env python
import os
import sys

if __name__ == "__main__":
    os.environ['DJANGO_SETTINGS_MODULE'] = 'crossix.settings'
    os.environ.setdefault('CROSSIX_APP_MODE', 'dev')

    from django.core.management import execute_from_command_line
    execute_from_command_line(sys.argv)



from . import models
from django.contrib import admin

class CategoryAdmin(admin.ModelAdmin):
    list_display = ['name', 'gender', 'min_age']
    list_filter = ['gender']


admin.site.register(models.Category, CategoryAdmin)


class ParticipantAdmin(admin.ModelAdmin):
    list_display = ['firstname', 'lastname', 'birthyear', 'gender', 'email', 'category', 'school', 'promo', 'last_edition']
    list_filter = ['gender', 'category', 'school', 'last_edition']

admin.site.register(models.Participant, ParticipantAdmin)


class EditionAdmin(admin.ModelAdmin):
    list_display = ['date', 'location', 'close_registrations']
    list_filter = ['location']

admin.site.register(models.Edition)



# -*- coding: utf-8 -*-

import datetime

from django import forms
from django.conf import settings
from django.contrib.auth.decorators import login_required
from django.template.context_processors import csrf
from django.shortcuts import render_to_response

from . import models


class ParticipantForm(forms.ModelForm):
    class Meta:
        model = models.Participant
        exclude = ('last_edition', )


def register(request):
    """Display the register form."""
    # CSRF protection
    ctxt = {
        'categories': models.Category.objects.all(),
    }
    ctxt.update(csrf(request))

    if request.method == 'POST':
        form = ParticipantForm(request.POST)
        if form.is_valid():
            ctxt['participant'] = form.save()
            return render_to_response('registrations/register_success.html', ctxt)
    else:
        form = ParticipantForm()
    ctxt['form'] = form
    return render_to_response('registrations/register.html', ctxt)


def index(request):
    """Display the index page."""
    next_edition = models.Edition.objects.next()
    last_edition = models.Edition.objects.last()
    ctxt = {
        'next_edition': next_edition,
        'last_edition': last_edition,
        }
    return render_to_response('registrations/index.html', ctxt)


def access(request):
    """Display the 'access' page."""
    edition = models.Edition.objects.next() or models.Edition.objects.last()
    ctxt = {
        'edition': edition,
    }
    return render_to_response('registrations/access.html', ctxt)


def list_participants(request):
    """Display the list of participants."""
    parts = {}
    next_edition = models.Edition.objects.next()
    for cat in models.Category.objects.filter():
        parts[cat] = models.Participant.objects.filter(category=cat, last_edition=next_edition)
    ctxt = {
            'categories': parts
            }
    return render_to_response('registrations/list.html', ctxt)


@login_required
def list_participants_full(request):
    """Display data about all participants."""
    ctxt = {
            'participants': models.Participant.objects.all()
            }
    return render_to_response('registrations/list_all.html', ctxt)



# -*- coding: utf-8 -*-
# Django settings for crossix project.

import os

import getconf

# Paths
# =====
BASE_DIR = os.path.dirname(__file__)
CHECKOUT_DIR = os.path.dirname(BASE_DIR)


# Global configuration
# ====================

config = getconf.ConfigGetter('crossix', [
    '/etc/crossix/*.ini',
    os.path.join(CHECKOUT_DIR, 'local_settings.ini'),
    ])


APPMODE = config.get('app.mode', 'prod')
assert APPMODE in ('dev', 'dist', 'prod'), "Invalid application mode %s" % APPMODE


# Generic Django settings
# =======================

# SECURITY WARNING: keep the secret key used in production secret!
if APPMODE in ('dev', 'dist'):
    _default_secret_key = 'Dev only!!'
else:
    _default_secret_key = ''

SECRET_KEY = config.get('app.secret_key', _default_secret_key)


# Debug
# =====

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = config.getbool('app.debug', APPMODE == 'dev')

if config.get('site.admin_mail'):
    ADMINS = (
        ("Cross-X admins", config.get('site.admin_mail')),
    )
    MANAGERS = ADMINS

if config.get('site.from_mail'):
    SERVER_EMAIL = config.get('site.from_mail')



# URLs
# ====

if APPMODE == 'dev':
    _default_url = 'http://example.org/'
else:
    _default_url = ''

ALLOWED_HOSTS = config.getlist('site.allowed_hosts')


# Loadable components
# ===================

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.admin',
    'crossix.registrations',
    'crossix.pages',
    'crossix',
)

MIDDLEWARE = (
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
)

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
            ],
        },
    },
]

ROOT_URLCONF = 'crossix.urls'

if APPMODE == 'dev':
    # Avoid the need for collectstatic before running tests
    STATICFILES_STORAGE = 'django.contrib.staticfiles.storage.StaticFilesStorage'
else:
    STATICFILES_STORAGE = 'django.contrib.staticfiles.storage.CachedStaticFilesStorage'


# Database
# ========

_ENGINE_MAP = {
    'sqlite': 'django.db.backends.sqlite3',
    'mysql': 'django.db.backends.mysql',
    'postgresql': 'django.db.backends.postgresql_psycopg2',
}
_engine = config.get('db.engine', 'sqlite')
if _engine not in _ENGINE_MAP:
    raise ImproperlyConfigured(
        "DB engine %s is unknown; please choose from %s"
        % (_engine, ', '.join(sorted(_ENGINE_MAP.keys())))
    )
if _engine == 'sqlite':
    if APPMODE == 'dev':
        _default_db_name = os.path.join(CHECKOUT_DIR, 'dev', 'db.sqlite')
    else:
        _default_db_name = '/var/lib/crossix/db.sqlite'
else:
    _default_db_name = 'crossix'


DATABASES = {
    'default': {
        'ENGINE': _ENGINE_MAP[_engine],
        'NAME': config.get('db.name', _default_db_name),
        'HOST': config.get('db.host'),
        'PORT': config.get('db.port'),
        'USER': config.get('db.user'),
        'PASSWORD': config.get('db.password'),
    }
}

# Internationalization
# ====================

TIME_ZONE = config.get('i18n.tz', 'Europe/Paris')

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = config.get('i18n.language', 'fr-fr')

USE_I18N = True
USE_L10N = True
USE_TZ = True

# Static files (CSS, JavaScript, Images)
# ======================================

STATIC_URL = config.get('site.assets_url', '/assets/')
STATIC_ROOT = os.path.join(BASE_DIR, 'assets')


# Uploads
# =======

if APPMODE == 'dev':
    _default_media = os.path.join(CHECKOUT_DIR, 'dev', 'media')
else:
    _default_media = ''

MEDIA_ROOT = config.get('uploads.dir', _default_media)
SENDFILE_BACKEND = 'sendfile.backends.%s' % config.get('uploads.serve', 'simple')
SENDFILE_ROOT = os.path.join(MEDIA_ROOT, 'crossix')
SENDFILE_URL = config.get('uploads.internal_url', '/uploads/')



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import codecs
import os
import re
import subprocess

from setuptools import setup, find_packages
from setuptools.command import build_py

root_dir = os.path.abspath(os.path.dirname(__file__))


def get_version(package_name):
    version_re = re.compile(r"^__version__ = [\"']([\w_.-]+)[\"']$")
    package_components = package_name.split('.')
    init_path = os.path.join(root_dir, *(package_components + ['__init__.py']))
    with codecs.open(init_path, 'r', 'utf-8') as f:
        for line in f:
            match = version_re.match(line[:-1])
            if match:
                return match.groups()[0]
    return ''


class BuildWithMakefile(build_py.build_py):
    """Custom 'build' command that runs 'make build' first."""
    def run(self):
        subprocess.check_call(['make', 'update-js'])
        subprocess.check_call(['make', 'build'])
        return super().run()


PACKAGE = 'crossix'


setup(
    # Contents
    name=PACKAGE,
    packages=find_packages(exclude=['dev', 'tests*']),
    include_package_data=True,
    scripts=['bin/crossixctl'],
    cmdclass={'build_py': BuildWithMakefile},
    zip_safe=False,

    # Metadata
    version=get_version(PACKAGE),
    description="Simple website for Cross triangulaire registration.",
    long_description=''.join(codecs.open('README.rst', 'r', 'utf-8').readlines()),
    author="Raphaël Barrois",
    author_email='raphael.barrois+%s@polytechnique.org' % PACKAGE,
    url='https://git.xelnor.net/%s/' % PACKAGE,
    keywords=['crossix'],
    license='MIT',

    # Dependencies
    install_requires=[
        'Django>=2.2',
        'django-sendfile2>=0.6.0',
        'getconf>=1.3.0',
        'markdown',
    ],

    # Misc
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
)



from django.conf.urls import *

# Uncomment the next two lines to enable the admin:
from django.contrib import admin
admin.autodiscover()

import django.contrib.auth.views

from .registrations import views

urlpatterns = [
    # Example:
    # (r'^cross_triangulaire/', include('cross_triangulaire.foo.urls')),
    url(r'^register/$', views.register, name='register'),
    url(r'^list/$', views.list_participants, name='list'),
    url(r'^listall/$', views.list_participants_full, name='listall'),
    url(r'^access/$', views.access, name='access'),
    url(r'^$', views.index, name='index'),

    url(r'^accounts/login/$', django.contrib.auth.views.LoginView.as_view(template_name='registrations/login.html')),

    # Uncomment the next line to enable the admin:
    url(r'^admin/', admin.site.urls),
]
